@@ -3,13 +3,18 @@ require 'rainbows/fiber'
 
 # A Fiber-based concurrency model for Ruby 1.9.  This uses a pool of
 # Fibers to handle client IO to run the application and the root Fiber
-# for scheduling and connection acceptance.  The pool size is equal to
-# the number of +worker_connections+.  Compared to the ThreadPool
-# model, Fibers are very cheap in terms of memory usage so you can
-# have more active connections.  This model supports a streaming
-# "rack.input" with lightweight concurrency.  Applications are
-# strongly advised to wrap all slow IO objects (sockets, pipes) using
-# the Rainbows::Fiber::IO class whenever possible.
+# for scheduling and connection acceptance.
+#
+# This concurrency model is difficult to use with existing applications,
+# lacks third-party support, and is thus NOT recommended.
+#
+# The pool size is equal to the number of +worker_connections+.
+# Compared to the ThreadPool model, Fibers are very cheap in terms of
+# memory usage so you can have more active connections.  This model
+# supports a streaming "rack.input" with lightweight concurrency.
+# Applications are strongly advised to wrap all slow IO objects
+# (sockets, pipes) using the Rainbows::Fiber::IO class whenever
+# possible.
 module Rainbows::FiberPool
   include Rainbows::Fiber::Base
 
@@ -19,7 +24,7 @@ module Rainbows::FiberPool
     worker_connections.times {
       Fiber.new {
         process(Fiber.yield) while pool << Fiber.current
-      }.resume # resume to hit ::Fiber.yield so it waits on a client
+      }.resume # resume to hit Fiber.yield so it waits on a client
     }
     Rainbows::Fiber::Base.setup(self.class, app)
 
@@ -34,6 +39,6 @@ module Rainbows::FiberPool
       end
     rescue => e
       Rainbows::Error.listen_loop(e)
-    end while G.alive || G.cur > 0
+    end while Rainbows.cur_alive
   end
 end
